@@ -13,6 +13,7 @@ import (
 	"github.com/azazeal/pause"
 
 	"github.com/superfly/flyctl/flyctl"
+	"github.com/superfly/flyctl/internal/buildinfo"
 	"github.com/superfly/flyctl/internal/filemu"
 	"github.com/superfly/flyctl/internal/logger"
 	"github.com/superfly/flyctl/internal/sentry"
@@ -35,7 +36,18 @@ func StartDaemon(ctx context.Context) (*Client, error) {
 	}
 
 	cmd := exec.Command(os.Args[0], "agent", "run", logFile)
-	cmd.Env = append(os.Environ(), "FLY_NO_UPDATE_CHECK=1")
+
+	env := os.Environ()
+	env = append(env, "FLY_NO_UPDATE_CHECK=1")
+
+	versionPre := buildinfo.Version().Pre
+
+	if len(versionPre) > 0 {
+		versionNum := versionPre[0].VersionNum
+		env = append(env, fmt.Sprintf("FLY_DEV_VERSION_NUM=%d", versionNum))
+	}
+
+	cmd.Env = env
 	setSysProcAttributes(cmd)
 
 	if err := cmd.Start(); err != nil {
