@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"net"
 	"os"
+	"runtime"
 	"time"
 
 	"github.com/AlecAivazis/survey/v2"
@@ -60,6 +61,10 @@ func stdArgsSSH(cmd *cobra.Command) {
 			Shorthand:   "A",
 			Description: "Address of VM to connect to",
 		},
+		flag.Bool{
+			Name:        "pty",
+			Description: "Allocate a pseudo-terminal (default: on when no command is provided)",
+		},
 	)
 }
 
@@ -188,6 +193,16 @@ func runConsole(ctx context.Context) error {
 		Stderr: ioutils.NewWriteCloserWrapper(colorable.NewColorableStderr(), func() error { return nil }),
 	}
 
+	// TODO: eventually remove the exception for sh and bash.
+	allocPTY := params.Cmd == "" || flag.GetBool(ctx, "pty")
+	if !allocPTY && (params.Cmd == "sh" || params.Cmd == "/bin/sh" || params.Cmd == "bash" || params.Cmd == "/bin/bash") {
+		terminal.Warn(
+			"Allocating a pseudo-terminal since the command provided is a shell. " +
+				"This behavior will change in the future; please use --pty explicitly if this is what you want.",
+		)
+		allocPTY = true
+	}
+
 	if quiet(ctx) {
 		params.DisableSpinner = true
 	}
@@ -198,11 +213,12 @@ func runConsole(ctx context.Context) error {
 		return err
 	}
 
-	term := &ssh.Terminal{
-		Stdin:  params.Stdin,
-		Stdout: params.Stdout,
-		Stderr: params.Stderr,
-		Mode:   "xterm",
+	sessIO := &ssh.SessionIO{
+		Stdin:    params.Stdin,
+		Stdout:   params.Stdout,
+		Stderr:   params.Stderr,
+		AllocPTY: allocPTY,
+		TermEnv:  determineTermEnv(),
 	}
 
 	currentStdin, currentStdout, currentStderr, err := setupConsole()
@@ -213,7 +229,7 @@ func runConsole(ctx context.Context) error {
 		return nil
 	}()
 
-	if err := sshc.Shell(params.Ctx, term, params.Cmd); err != nil {
+	if err := sshc.Shell(params.Ctx, sessIO, params.Cmd); err != nil {
 		captureError(err, app)
 		return errors.Wrap(err, "ssh shell")
 	}
@@ -387,3 +403,38 @@ func addrForNomad(ctx context.Context, agentclient *agent.Client, app *api.AppCo
 	}
 	return instances.Addresses[0], nil
 }
+
+const defaultTermEnv = "xterm"
+
+func determineTermEnv() string {
+	switch runtime.GOOS {
+	case "aix":
+		return determineTermEnvFromLocalEnv()
+	case "darwin":
+		return determineTermEnvFromLocalEnv()
+	case "dragonfly":
+		return determineTermEnvFromLocalEnv()
+	case "freebsd":
+		return determineTermEnvFromLocalEnv()
+	case "illumos":
+		return determineTermEnvFromLocalEnv()
+	case "linux":
+		return determineTermEnvFromLocalEnv()
+	case "netbsd":
+		return determineTermEnvFromLocalEnv()
+	case "openbsd":
+		return determineTermEnvFromLocalEnv()
+	case "solaris":
+		return determineTermEnvFromLocalEnv()
+	default:
+		return defaultTermEnv
+	}
+}
+
+func determineTermEnvFromLocalEnv() string {
+	if term := os.Getenv("TERM"); term != "" {
+		return term
+	} else {
+		return defaultTermEnv
+	}
+}
